@@ -14,10 +14,14 @@
 
 import datetime
 
-from grpc.experimental import aio
 import mock
 import pytest
 
+try:
+    from grpc import aio
+except ImportError:
+    pytest.skip("No GRPC", allow_module_level=True)
+
 from google.api_core import exceptions
 from google.api_core import gapic_v1
 from google.api_core import grpc_helpers_async
